@@ -20,7 +20,7 @@ if "ipykernel" in sys.modules:
     from IPython.core.magic import Magics, line_cell_magic, magics_class  # type: ignore
     from IPython.display import Markdown, display  # type: ignore
 
-    from .cli.cli_tag import main
+    from paroxython.cli.cli_tag import main
 
     def load_ipython_extension(ipython):
         ipython.register_magics(ParoxythonMagics)
