@@ -84,8 +84,8 @@ from typing import Set, Callable
 
 import regex  # type: ignore
 
-from .goodies import couple_to_string
-from .user_types import Label, LabelName, Labels, LabelsSpans, Query, Span
+from paroxython.goodies import couple_to_string
+from paroxython.user_types import Label, LabelName, Labels, LabelsSpans, Query, Span
 
 
 class DerivedLabelsDatabase:
