@@ -54,7 +54,7 @@ from typing import Callable, Dict, List, Tuple, Set
 
 import regex  # type: ignore
 
-from .user_types import LabelName, LabelsSpans, Source, Span
+from paroxython.user_types import LabelName, LabelsSpans, Source, Span
 
 HINT_COMMENT = "# paroxython:"
 
