@@ -28,8 +28,9 @@ class Label(NamedTuple):
 Labels = List[Label]
 LabelsSpans = Dict[LabelName, List[Span]]
 
+LabelPattern = NewType("LabelPattern", str)
 
-# Taxons
+# Taxa
 
 TaxonName = NewType("TaxonName", str)
 TaxonNames = List[TaxonName]
@@ -39,9 +40,11 @@ class Taxon(NamedTuple):
     name: TaxonName
     spans: Bag[Span]
 
-Taxons = List[Taxon]
-TaxonsSpans = Dict[TaxonName, Bag[Span]]
+Taxa = List[Taxon]
+TaxaSpans = Dict[TaxonName, Bag[Span]]
 
+TaxonPattern = NewType("TaxonPattern", str)
+TaxonPatterns = List[TaxonPattern]
 
 # Programs
 
@@ -51,26 +54,26 @@ ProgramNameSet = Set[ProgramName]
 
 class Program(NamedTuple):
     labels: Labels
-    taxons: Taxons
+    taxa: Taxa
     addition: LabelsSpans
     deletion: LabelsSpans
     name: ProgramName = ProgramName("")
     source: Source = Source("")
 
 Programs = List[Program]
-ProgramTaxons = Dict[ProgramName, Taxons]
+ProgramTaxa = Dict[ProgramName, Taxa]
 
 # Serialization-ready types used for the JSON database
 
 PoorSpan = Tuple[int, int]
 LabelsPoorSpans = Dict[LabelName, List[PoorSpan]]
-TaxonsPoorSpans = Dict[TaxonName, List[PoorSpan]]
+TaxaPoorSpans = Dict[TaxonName, List[PoorSpan]]
 
 class ProgramRecord(TypedDict):
     timestamp: str
     source: Source
     labels: LabelsPoorSpans
-    taxons: TaxonsPoorSpans
+    taxa: TaxaPoorSpans
 
 ProgramInfos = Dict[ProgramName, ProgramRecord]
 LabelInfos = Dict[LabelName, ProgramNames]
@@ -80,7 +83,7 @@ ProgramToPrograms = Dict[ProgramName, ProgramNames]
 class JsonDatabase(TypedDict):
     programs: ProgramInfos
     labels: LabelInfos
-    taxons: TaxonInfos
+    taxa: TaxonInfos
     importations: ProgramToPrograms
     exportations: ProgramToPrograms
 
@@ -95,18 +98,19 @@ class JsonDatabase(TypedDict):
 # - trailing commas;
 # - comments!
 
-Operation = Literal["include", "exclude", "impart"]
+Operation = NewType("Operation", str)
+
+Criterion = Union[str, Tuple[str, str, str]] # either a pattern or a semantic triple
 
 class Command(TypedDict):
     operation: Operation
-    source: Union[str, List[str]] # not source code, but source of the data
+    data: Union[str, List[Criterion]]
     filtered_out: ProgramNames # to be populated by the execution of the command
 
 Predicate = Callable[[int, int], bool]
 
 # Recommendations
 
-ProgramTaxonNames = Dict[ProgramName, TaxonNames]
 AssessedPrograms = List[Tuple[float, ProgramName]]
 
 AssessmentStrategy = Literal["zeno", "linear"]
